@@ -1,4 +1,4 @@
-# Copyright 2015-2016 Google Inc. All Rights Reserved.
+# Copyright 2015-2017 Google Inc. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,7 +19,6 @@ This is a thin wrapper around a pytree.Leaf node.
 import keyword
 import re
 
-from lib2to3 import pytree
 from lib2to3.pgen2 import token
 
 from yapf.yapflib import py3compat
@@ -47,11 +46,15 @@ class Subtype(object):
   KWARGS_STAR_STAR = 9
   ASSIGN_OPERATOR = 10
   DICTIONARY_KEY = 11
-  DICTIONARY_VALUE = 12
-  DICT_SET_GENERATOR = 13
-  COMP_FOR = 14
-  COMP_IF = 15
-  FUNC_DEF = 16
+  DICTIONARY_KEY_PART = 12
+  DICTIONARY_VALUE = 13
+  DICT_SET_GENERATOR = 14
+  COMP_FOR = 15
+  COMP_IF = 16
+  FUNC_DEF = 17
+  DECORATOR = 18
+  TYPED_NAME = 19
+  TYPED_NAME_ARG_LIST = 20
 
 
 class FormatToken(object):
@@ -119,8 +122,9 @@ class FormatToken(object):
       indent_level: (int) The indentation level.
     """
     indent_char = '\t' if style.Get('USE_TABS') else ' '
-    indent_before = (
-        indent_char * indent_level * style.Get('INDENT_WIDTH') + ' ' * spaces)
+    token_indent_char = indent_char if newlines_before > 0 else ' '
+    indent_before = (indent_char * indent_level * style.Get('INDENT_WIDTH') +
+                     token_indent_char * spaces)
 
     if self.is_comment:
       comment_lines = [s.lstrip() for s in self.value.splitlines()]
@@ -143,9 +147,14 @@ class FormatToken(object):
   def RetainHorizontalSpacing(self, first_column, depth):
     """Retains a token's horizontal spacing."""
     previous = self.previous_token
-    if previous is None:
+    if not previous:
       return
 
+    if previous.is_pseudo_paren:
+      previous = previous.previous_token
+      if not previous:
+        return
+
     cur_lineno = self.lineno
     prev_lineno = previous.lineno
     if previous.is_multiline_string:
@@ -170,6 +179,7 @@ class FormatToken(object):
       prev_len = len(previous.value.split('\n')[-1])
       if '\n' in previous.value:
         prev_column = 0  # Last line starts in column 0.
+
     self.spaces_required_before = cur_column - (prev_column + prev_len)
 
   def OpensScope(self):
