@@ -278,6 +278,43 @@ class FormatFileTest(unittest.TestCase):
       formatted_code, _, _ = yapf_api.FormatFile(filepath, style_config='pep8')
       self.assertCodeEqual(code, formatted_code)
 
+  def testSplittingSemicolonStatements(self):
+    unformatted_code = textwrap.dedent(u"""\
+        def f():
+          x = y + 42 ; z = n * 42
+          if True: a += 1 ; b += 1; c += 1
+        """)
+    expected_formatted_code = textwrap.dedent(u"""\
+        def f():
+            x = y + 42
+            z = n * 42
+            if True:
+                a += 1
+                b += 1
+                c += 1
+        """)
+    with utils.TempFileContents(self.test_tmpdir, unformatted_code) as filepath:
+      formatted_code, _, _ = yapf_api.FormatFile(filepath, style_config='pep8')
+      self.assertCodeEqual(expected_formatted_code, formatted_code)
+
+  def testSemicolonStatementsDisabled(self):
+    unformatted_code = textwrap.dedent(u"""\
+        def f():
+          x = y + 42 ; z = n * 42  # yapf: disable
+          if True: a += 1 ; b += 1; c += 1
+        """)
+    expected_formatted_code = textwrap.dedent(u"""\
+        def f():
+            x = y + 42 ; z = n * 42  # yapf: disable
+            if True:
+                a += 1
+                b += 1
+                c += 1
+        """)
+    with utils.TempFileContents(self.test_tmpdir, unformatted_code) as filepath:
+      formatted_code, _, _ = yapf_api.FormatFile(filepath, style_config='pep8')
+      self.assertCodeEqual(expected_formatted_code, formatted_code)
+
   def testDisabledSemiColonSeparatedStatements(self):
     code = textwrap.dedent(u"""\
         # yapf: disable
@@ -1160,6 +1197,68 @@ class CommandLineTest(unittest.TestCase):
           expected_formatted_code,
           extra_options=['--style={0}'.format(stylepath)])
 
+  def testSpacingBeforeComments(self):
+    unformatted_code = textwrap.dedent("""\
+        A = 42
+
+
+        # A comment
+        def x():
+            pass
+        def _():
+            pass
+        """)
+    expected_formatted_code = textwrap.dedent("""\
+        A = 42
+
+
+        # A comment
+        def x():
+            pass
+        def _():
+            pass
+        """)
+    self.assertYapfReformats(
+        unformatted_code,
+        expected_formatted_code,
+        extra_options=['--lines', '1-2'])
+
+  def testSpacingBeforeCommentsInDicts(self):
+    unformatted_code = textwrap.dedent("""\
+        A=42
+
+        X = {
+            # 'Valid' statuses.
+            PASSED:  # Passed
+                'PASSED',
+            FAILED:  # Failed
+                'FAILED',
+            TIMED_OUT:  # Timed out.
+                'FAILED',
+            BORKED:  # Broken.
+                'BROKEN'
+        }
+        """)
+    expected_formatted_code = textwrap.dedent("""\
+        A = 42
+
+        X = {
+            # 'Valid' statuses.
+            PASSED:  # Passed
+                'PASSED',
+            FAILED:  # Failed
+                'FAILED',
+            TIMED_OUT:  # Timed out.
+                'FAILED',
+            BORKED:  # Broken.
+                'BROKEN'
+        }
+        """)
+    self.assertYapfReformats(
+        unformatted_code,
+        expected_formatted_code,
+        extra_options=['--style', 'chromium', '--lines', '1-1'])
+
 
 class BadInputTest(unittest.TestCase):
   """Test yapf's behaviour when passed bad input."""
